@@ -26,11 +26,18 @@
 #ifndef _ORBIT_CORBA_ANY_H_
 #define _ORBIT_CORBA_ANY_H_
 
+#include "orbit_types.h"
+#include "corba_typecode.h"
+
+#include <unistd.h>
+
 typedef struct CORBA_any_type CORBA_any;
 
+size_t ORBit_gather_alloc_info(CORBA_TypeCode tc);
+gint ORBit_find_alignment(CORBA_TypeCode tc);
+CORBA_TypeCode ORBit_get_union_tag(CORBA_TypeCode union_tc,
+				   gpointer *val);
+gpointer ORBit_copy_value(gpointer value, CORBA_TypeCode tc);
+void CORBA_any__copy(CORBA_any *out, CORBA_any *in);
+
 #endif /* !_ORBIT_CORBA_ANY_H_ */
-
-
-
-
-
